@@ -1,5 +1,8 @@
 var NAVTREEINDEX21 =
 {
+"structspa__graph__node.html#a7a4bea046f4d6a88d97e12a5297ed740":[8,9,5,5,1],
+"structspa__graph__node.html#ab16592a35d02f827271786b49110341c":[8,9,5,5,7],
+"structspa__graph__node.html#acbee04440eefb9b0a77f69ff1876dbc0":[8,9,5,5,6],
 "structspa__graph__node.html#acfb4e7658140701927336dee05ed1948":[8,9,5,5,3],
 "structspa__graph__node.html#ada29bc9109cd890c74cfba630989b76c":[8,9,5,5,5],
 "structspa__graph__node.html#aec1169015c1d7a4aaea10d5f4946f7d4":[8,9,5,5,2],
@@ -246,8 +249,5 @@ var NAVTREEINDEX21 =
 "structspa__node__callbacks.html#a597eb6e41252d8030e4d697b51406ad0":[8,9,6,25,3],
 "structspa__node__events.html":[8,9,6,24],
 "structspa__node__events.html#a37b6ed18688f456b4c4e9b157879414f":[8,9,6,24,0],
-"structspa__node__events.html#a4b3918e0034bb87549fe911028ca8741":[8,9,6,24,4],
-"structspa__node__events.html#a64cd08176057e03e97babf5b36ecd7bf":[8,9,6,24,3],
-"structspa__node__events.html#a6950a2df9f758cbbe7651f9db3962bed":[8,9,6,24,1],
-"structspa__node__events.html#a7915d7cc4ad14d41c0a0865798470429":[8,9,6,24,2]
+"structspa__node__events.html#a4b3918e0034bb87549fe911028ca8741":[8,9,6,24,4]
 };
